import 'package:flutter/material.dart';
import 'app_bar_controller.dart';

class SearchAppBar extends StatelessWidget implements PreferredSizeWidget {
  final Color statusBarColor;
  final Color primary;
  final bool autoSelected;
  final AppBar mainAppBar;
  final Color mainTextColor;
  final String searchHint;
  final AppBarController appBarController;
  final Function(String search) onChange;

  SearchAppBar({
    @required this.primary,
    this.mainTextColor = Colors.white,
    this.statusBarColor,
    this.autoSelected = false,
    this.searchHint = "Search here...",
    @required this.mainAppBar,
    @required this.appBarController,
    @required this.onChange,
  });

  @override
  Size get preferredSize {
    return Size.fromHeight(60.0);
  }

  Widget build(BuildContext context) {
    appBarController.stream.add(autoSelected);

    return StreamBuilder(
      stream: appBarController.stream.stream,
      builder: (BuildContext context, AsyncSnapshot<bool> snap) {
        if (appBarController.state) {
          return searchAppBar(context: context,);
        } else {
          return showMainAppBar();
        }
      },
    );
  }

  Widget showMainAppBar() {
    return mainAppBar;
  }

  Widget searchAppBar({@required BuildContext context}) {
    return 
        AppBar(
          leading: InkWell(
            child: Icon(Icons.close),
            onTap: () {
              appBarController.stream.add(false);
            },
          ),
          backgroundColor: primary,
          title: TextField(
            // onChanged: (String value){
            //   onChange(value);
            // },
            decoration: InputDecoration(
              hintText: searchHint,
              border: InputBorder.none,
              hintStyle: TextStyle(

              ),
              prefixIcon: Icon(Icons.search),

            ),
          ),
        );
  }
}
